<Query Kind="Statements" />

// Should you wish to also write a constructor, you can apply the [SetsRequiredMembers]
// attribute to bypass the required member restriction for that constructor:
// Consumers can now benefit from the convenience of that constructor without any tradeoff:

Asset a1 = new Asset { Name = "House" };  // OK
Asset a2 = new Asset ("House");           // OK
Asset a3 = new Asset();                   // Error!

// Notice that we also defined a parameterless constructor (for use with the object initializer).
// Its presence also ensures that subclasses remain under no burden to reproduce any constructor.
// In the following example, the House class chooses not to implement a convenience constructor:

House h1 = new House { Name = "House" };  // OK
House h2 = new House();                   // Error!

Asset a4 = new Asset { Name = "House" };  // OK
Asset a5 = new Asset();                   // Error: will not compile!

public class House : Asset { }            // No constructor, no worries!

public class Asset
{
	public required string Name;

	public Asset() { }

	[System.Diagnostics.CodeAnalysis.SetsRequiredMembers]
	public Asset (string n) => Name = n;
}
