<Query Kind="Statements" />

// The nint and unint native-sized integer types are sized to match the address space
// of the processor and operating system at runtime (in practice, 32 or 64 bits).

// Native-sized integers behave much like standard integers, with support
// for arithmetic operations, overflow check operators, and so on:

nint x = 123;
nint y = 234;
checked
{
	nint sum = x + y, product = x * y;
	product.Dump();
}

// When working with pointers, native-sized integers can improve efficiency because the 
// result of subtracting two pointers in C# is always a 64-bit integer (long), which is 
// inefficient  on 32-bit platforms. By first casting the pointers to nint, the result 
// of a subtraction is also nint (which will be 32 bits on a 32-bit platform):

unsafe nint AddressDif (char* x, char* y) => (nint)x - (nint)y;

// When targeting .NET 7 or later, nint and nuint act as synonyms for the underlying
// .NET types System.IntPtr and System.UIntPtr.

// When .NET 6 or below (or.NET Standard), nint and nuint still use IntPtr and UIntPtr
// as their underlying types. However, because the legacy IntPtr and UIntPtr types lack
// support for most arithmetic operations, the compiler fills in the gaps, making the
// nint/nuint types behave as they would in .NET 7+ (including allowing checked operations).

nint native = 123;
Console.WriteLine (native * native);   // Works on .NET 6 (as well as later versions)

IntPtr ip = native;
Console.WriteLine (ip * ip);           // Requires .NET 7+

